import 'dart:developer';

import 'package:flutter_webrtc/flutter_webrtc.dart';
import 'package:videosdk/videosdk.dart';

enum CustomTrackKind { AUDIO, VIDEO, SHARE }

class CustomTrack {
  late MediaStream mediaStream;
  late CustomVideoTrackConfig videoEncoderConfig;
  late CustomAudioTrackConfig audioEncoderConfig;
  late Map<String, bool>? noiseConfig;
  late CustomTrackKind kind;
  late bool multiStream;
  // late String optimizationMode;

  CustomTrack.videoTrack({
    required this.mediaStream,
    this.kind = CustomTrackKind.VIDEO,
    this.videoEncoderConfig = CustomVideoTrackConfig.h720p_w1280p,
    this.multiStream = true,
    // this.optimizationMode = "motion",
  });

  CustomTrack.audioTrack({
    required this.mediaStream,
    this.audioEncoderConfig = CustomAudioTrackConfig.speech_standard,
    this.noiseConfig,
    this.kind = CustomTrackKind.AUDIO,
  });

  dispose() async {
    try {
      mediaStream.getTracks().forEach((track) {
        track.onEnded = null;
        track.stop();
      });
    } catch (error) {
      log("ERROR: Unable to dispose track :: $error");
    }
  }
}
